

from .chunk_splitter import ChunkSplitter
from .document_byte_text_extraction_response import DocumentByteTextExtractionResponse
from .document_chunk import DocumentChunk
from .document_extraction_response import DocumentExtractionResponse
from .document_extraction_response_with_embeddings import DocumentExtractionResponseWithEmbeddings
from .document_extraction_result import DocumentExtractionResult
from .document_file_text_extraction_response import DocumentFileTextExtractionResponse
from .document_usage import DocumentUsage
from .document_with_embeddings_usage import DocumentWithEmbeddingsUsage
from .embedding import Embedding
from .embeddings_response import EmbeddingsResponse
from .http_validation_error import HttpValidationError
from .usage import Usage
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .whisper_response import WhisperResponse
from .whisper_result import WhisperResult
from .whisper_usage import WhisperUsage

__all__ = [
    "ChunkSplitter",
    "DocumentChunk",
    "DocumentExtractionResponse",
    "DocumentExtractionResponseWithEmbeddings",
    "DocumentExtractionResult",
    "DocumentUsage",
    "DocumentWithEmbeddingsUsage",
    "Embedding",
    "EmbeddingsResponse",
    "DocumentFileTextExtractionResponse",
    "DocumentByteTextExtractionResponse",
    "HttpValidationError",
    "Usage",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhisperResponse",
    "WhisperResult",
    "WhisperUsage",
]





import datetime as dt


def serialize_datetime(v: dt.datetime) -> str:
    """
    Serialize a datetime including timezone info.

    Uses the timezone info provided if present, otherwise uses the current runtime's timezone info.

    UTC datetimes end in "Z" while all other timezones are represented as offset from UTC, e.g. +05:00.
    """

    def _serialize_zoned_datetime(v: dt.datetime) -> str:
        if v.tzinfo is not None and v.tzinfo.tzname(None) == dt.timezone.utc.tzname(None):
            # UTC is a special case where we use "Z" at the end instead of "+00:00"
            return v.isoformat().replace("+00:00", "Z")
        else:
            # Delegate to the typical +/- offset format
            return v.isoformat()

    if v.tzinfo is not None:
        return _serialize_zoned_datetime(v)
    else:
        local_tz = dt.datetime.now().astimezone().tzinfo
        localized_dt = v.replace(tzinfo=local_tz)
        return _serialize_zoned_datetime(localized_dt)





from typing import Dict, Optional


def remove_none_from_headers(headers: Dict[str, Optional[str]]) -> Dict[str, str]:
    new_headers: Dict[str, str] = {}
    for header_key, header_value in headers.items():
        if header_value is not None:
            new_headers[header_key] = header_value
    return new_headers





import datetime as dt
import typing

import pydantic

from .document_extraction_result import DocumentExtractionResult
from .document_with_embeddings_usage import DocumentWithEmbeddingsUsage
from ..core.datetime_utils import serialize_datetime


class DocumentExtractionResponseWithEmbeddings(pydantic.BaseModel):
    usage: DocumentWithEmbeddingsUsage
    data: DocumentExtractionResult
    model: str

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}
